@@ -9,6 +9,7 @@ aux1 = insFld(aux0, gFld("Calculation Modes", "vars/Calculation_Modes.html#Calcu
 insDoc(aux1, gLnk("R", "CalculationMode", "vars/Calculation_Modes.html#CalculationMode"))
 aux2 = insFld(aux1, gFld("Geometry Optimization", "vars/Calculation_Modes.html#Calculation_Modes::Geometry_Optimization"))
 insDoc(aux2, gLnk("R", "GOCenter", "vars/Calculation_Modes.html#GOCenter"))
+insDoc(aux2, gLnk("R", "GOConstrains", "vars/Calculation_Modes.html#GOConstrains"))
 insDoc(aux2, gLnk("R", "GOFireIntegrator", "vars/Calculation_Modes.html#GOFireIntegrator"))
 insDoc(aux2, gLnk("R", "GOFireMass", "vars/Calculation_Modes.html#GOFireMass"))
 insDoc(aux2, gLnk("R", "GOLineTol", "vars/Calculation_Modes.html#GOLineTol"))
@@ -18,6 +19,9 @@ insDoc(aux2, gLnk("R", "GOMinimumMove", "vars/Calculation_Modes.html#GOMinimumMo
 insDoc(aux2, gLnk("R", "GOObjective", "vars/Calculation_Modes.html#GOObjective"))
 insDoc(aux2, gLnk("R", "GOStep", "vars/Calculation_Modes.html#GOStep"))
 insDoc(aux2, gLnk("R", "GOTolerance", "vars/Calculation_Modes.html#GOTolerance"))
+insDoc(aux2, gLnk("R", "PDBGOConstrains", "vars/Calculation_Modes.html#PDBGOConstrains"))
+insDoc(aux2, gLnk("R", "XSFGOConstrains", "vars/Calculation_Modes.html#XSFGOConstrains"))
+insDoc(aux2, gLnk("R", "XYZGOConstrains", "vars/Calculation_Modes.html#XYZGOConstrains"))
 aux2 = insFld(aux1, gFld("Invert KS", "vars/Calculation_Modes.html#Calculation_Modes::Invert_KS"))
 insDoc(aux2, gLnk("R", "InvertKSConvAbsDens", "vars/Calculation_Modes.html#InvertKSConvAbsDens"))
 insDoc(aux2, gLnk("R", "InvertKSGodbyMu", "vars/Calculation_Modes.html#InvertKSGodbyMu"))
@@ -98,6 +102,7 @@ insDoc(aux2, gLnk("R", "OpenCLBenchmark", "vars/Execution.html#OpenCLBenchmark")
 insDoc(aux2, gLnk("R", "OpenCLDevice", "vars/Execution.html#OpenCLDevice"))
 insDoc(aux2, gLnk("R", "OpenCLPlatform", "vars/Execution.html#OpenCLPlatform"))
 aux2 = insFld(aux1, gFld("Optimization", "vars/Execution.html#Execution::Optimization"))
+insDoc(aux2, gLnk("R", "HamiltonianApplyPacked", "vars/Execution.html#HamiltonianApplyPacked"))
 insDoc(aux2, gLnk("R", "MemoryLimit", "vars/Execution.html#MemoryLimit"))
 insDoc(aux2, gLnk("R", "MeshBlockSize", "vars/Execution.html#MeshBlockSize"))
 insDoc(aux2, gLnk("R", "MeshOrder", "vars/Execution.html#MeshOrder"))
@@ -170,19 +175,38 @@ insDoc(aux2, gLnk("R", "ComplexScalingLocalizedStates", "vars/Hamiltonian.html#C
 insDoc(aux2, gLnk("R", "ComplexScalingPenalizationFactor", "vars/Hamiltonian.html#ComplexScalingPenalizationFactor"))
 insDoc(aux2, gLnk("R", "ComplexScalingRotateSpectrum", "vars/Hamiltonian.html#ComplexScalingRotateSpectrum"))
 insDoc(aux2, gLnk("R", "ComplexScalingTheta", "vars/Hamiltonian.html#ComplexScalingTheta"))
+aux2 = insFld(aux1, gFld("DFT+U", "vars/Hamiltonian.html#Hamiltonian::DFT+U"))
+insDoc(aux2, gLnk("R", "AOLoewdin", "vars/Hamiltonian.html#AOLoewdin"))
+insDoc(aux2, gLnk("R", "AONormalize", "vars/Hamiltonian.html#AONormalize"))
+insDoc(aux2, gLnk("R", "AOSubmeshForPeriodic", "vars/Hamiltonian.html#AOSubmeshForPeriodic"))
+insDoc(aux2, gLnk("R", "AOThreshold", "vars/Hamiltonian.html#AOThreshold"))
+insDoc(aux2, gLnk("R", "AOTruncation", "vars/Hamiltonian.html#AOTruncation"))
+insDoc(aux2, gLnk("R", "SkipSOrbitals", "vars/Hamiltonian.html#SkipSOrbitals"))
+insDoc(aux2, gLnk("R", "UseAllAtomicOrbitals", "vars/Hamiltonian.html#UseAllAtomicOrbitals"))
 aux2 = insFld(aux1, gFld("PCM", "vars/Hamiltonian.html#Hamiltonian::PCM"))
 insDoc(aux2, gLnk("R", "PCMCalcMethod", "vars/Hamiltonian.html#PCMCalcMethod"))
 insDoc(aux2, gLnk("R", "PCMCalculation", "vars/Hamiltonian.html#PCMCalculation"))
 insDoc(aux2, gLnk("R", "PCMCavity", "vars/Hamiltonian.html#PCMCavity"))
 insDoc(aux2, gLnk("R", "PCMChargeSmearNN", "vars/Hamiltonian.html#PCMChargeSmearNN"))
+insDoc(aux2, gLnk("R", "PCMDebyeRelaxTime", "vars/Hamiltonian.html#PCMDebyeRelaxTime"))
+insDoc(aux2, gLnk("R", "PCMDrudeLDamping", "vars/Hamiltonian.html#PCMDrudeLDamping"))
+insDoc(aux2, gLnk("R", "PCMDrudeLOmega", "vars/Hamiltonian.html#PCMDrudeLOmega"))
 insDoc(aux2, gLnk("R", "PCMDynamicEpsilon", "vars/Hamiltonian.html#PCMDynamicEpsilon"))
+insDoc(aux2, gLnk("R", "PCMEoM", "vars/Hamiltonian.html#PCMEoM"))
+insDoc(aux2, gLnk("R", "PCMEoMInitialCharges", "vars/Hamiltonian.html#PCMEoMInitialCharges"))
+insDoc(aux2, gLnk("R", "PCMEpsilonModel", "vars/Hamiltonian.html#PCMEpsilonModel"))
 insDoc(aux2, gLnk("R", "PCMGamessBenchmark", "vars/Hamiltonian.html#PCMGamessBenchmark"))
+insDoc(aux2, gLnk("R", "PCMKick", "vars/Hamiltonian.html#PCMKick"))
+insDoc(aux2, gLnk("R", "PCMLocalField", "vars/Hamiltonian.html#PCMLocalField"))
+insDoc(aux2, gLnk("R", "PCMNonequilibrium", "vars/Hamiltonian.html#PCMNonequilibrium"))
 insDoc(aux2, gLnk("R", "PCMQtotTol", "vars/Hamiltonian.html#PCMQtotTol"))
 insDoc(aux2, gLnk("R", "PCMRadiusScaling", "vars/Hamiltonian.html#PCMRadiusScaling"))
 insDoc(aux2, gLnk("R", "PCMRenormCharges", "vars/Hamiltonian.html#PCMRenormCharges"))
 insDoc(aux2, gLnk("R", "PCMSmearingFactor", "vars/Hamiltonian.html#PCMSmearingFactor"))
+insDoc(aux2, gLnk("R", "PCMSolute", "vars/Hamiltonian.html#PCMSolute"))
 insDoc(aux2, gLnk("R", "PCMSpheresOnH", "vars/Hamiltonian.html#PCMSpheresOnH"))
 insDoc(aux2, gLnk("R", "PCMStaticEpsilon", "vars/Hamiltonian.html#PCMStaticEpsilon"))
+insDoc(aux2, gLnk("R", "PCMTessMinDistance", "vars/Hamiltonian.html#PCMTessMinDistance"))
 insDoc(aux2, gLnk("R", "PCMTessSubdivider", "vars/Hamiltonian.html#PCMTessSubdivider"))
 insDoc(aux2, gLnk("R", "PCMUpdateIter", "vars/Hamiltonian.html#PCMUpdateIter"))
 insDoc(aux2, gLnk("R", "PCMVdWRadii", "vars/Hamiltonian.html#PCMVdWRadii"))
@@ -212,6 +236,7 @@ insDoc(aux2, gLnk("R", "TnaddFactor", "vars/Hamiltonian.html#TnaddFactor"))
 insDoc(aux2, gLnk("R", "TnaddFunctional", "vars/Hamiltonian.html#TnaddFunctional"))
 insDoc(aux2, gLnk("R", "TnaddPolarized", "vars/Hamiltonian.html#TnaddPolarized"))
 aux2 = insFld(aux1, gFld("XC", "vars/Hamiltonian.html#Hamiltonian::XC"))
+insDoc(aux2, gLnk("R", "DFTULevel", "vars/Hamiltonian.html#DFTULevel"))
 insDoc(aux2, gLnk("R", "Interaction1D", "vars/Hamiltonian.html#Interaction1D"))
 insDoc(aux2, gLnk("R", "Interaction1DScreening", "vars/Hamiltonian.html#Interaction1DScreening"))
 insDoc(aux2, gLnk("R", "LB94_modified", "vars/Hamiltonian.html#LB94_modified"))
@@ -220,6 +245,7 @@ insDoc(aux2, gLnk("R", "OEPLevel", "vars/Hamiltonian.html#OEPLevel"))
 insDoc(aux2, gLnk("R", "OEPMixing", "vars/Hamiltonian.html#OEPMixing"))
 insDoc(aux2, gLnk("R", "SICCorrection", "vars/Hamiltonian.html#SICCorrection"))
 insDoc(aux2, gLnk("R", "VDWCorrection", "vars/Hamiltonian.html#VDWCorrection"))
+insDoc(aux2, gLnk("R", "VDWD3Functional", "vars/Hamiltonian.html#VDWD3Functional"))
 insDoc(aux2, gLnk("R", "VDWSelfConsistent", "vars/Hamiltonian.html#VDWSelfConsistent"))
 insDoc(aux2, gLnk("R", "XCFunctional", "vars/Hamiltonian.html#XCFunctional"))
 insDoc(aux2, gLnk("R", "XCKernel", "vars/Hamiltonian.html#XCKernel"))
@@ -247,9 +273,11 @@ insDoc(aux2, gLnk("R", "CasidaHermitianConjugate", "vars/Linear_Response.html#Ca
 insDoc(aux2, gLnk("R", "CasidaKSEnergyWindow", "vars/Linear_Response.html#CasidaKSEnergyWindow"))
 insDoc(aux2, gLnk("R", "CasidaKohnShamStates", "vars/Linear_Response.html#CasidaKohnShamStates"))
 insDoc(aux2, gLnk("R", "CasidaMomentumTransfer", "vars/Linear_Response.html#CasidaMomentumTransfer"))
+insDoc(aux2, gLnk("R", "CasidaPrintExcitations", "vars/Linear_Response.html#CasidaPrintExcitations"))
 insDoc(aux2, gLnk("R", "CasidaQuadratureOrder", "vars/Linear_Response.html#CasidaQuadratureOrder"))
 insDoc(aux2, gLnk("R", "CasidaTheoryLevel", "vars/Linear_Response.html#CasidaTheoryLevel"))
 insDoc(aux2, gLnk("R", "CasidaTransitionDensities", "vars/Linear_Response.html#CasidaTransitionDensities"))
+insDoc(aux2, gLnk("R", "CasidaWeightThreshold", "vars/Linear_Response.html#CasidaWeightThreshold"))
 aux2 = insFld(aux1, gFld("KdotP", "vars/Linear_Response.html#Linear_Response::KdotP"))
 insDoc(aux2, gLnk("R", "KdotPCalcSecondOrder", "vars/Linear_Response.html#KdotPCalcSecondOrder"))
 insDoc(aux2, gLnk("R", "KdotPCalculateEffectiveMasses", "vars/Linear_Response.html#KdotPCalculateEffectiveMasses"))
@@ -367,7 +395,9 @@ insDoc(aux2, gLnk("R", "Radius", "vars/Mesh.html#Radius"))
 insDoc(aux2, gLnk("R", "SymmetryBreakDir", "vars/Mesh.html#SymmetryBreakDir"))
 insDoc(aux2, gLnk("R", "Xlength", "vars/Mesh.html#Xlength"))
 aux1 = insFld(aux0, gFld("Output", "vars/Output.html#Output"))
+insDoc(aux1, gLnk("R", "BandStructureComputeProjections", "vars/Output.html#BandStructureComputeProjections"))
 insDoc(aux1, gLnk("R", "CurrentThroughPlane", "vars/Output.html#CurrentThroughPlane"))
+insDoc(aux1, gLnk("R", "DOSComputePDOS", "vars/Output.html#DOSComputePDOS"))
 insDoc(aux1, gLnk("R", "DOSEnergyMax", "vars/Output.html#DOSEnergyMax"))
 insDoc(aux1, gLnk("R", "DOSEnergyMin", "vars/Output.html#DOSEnergyMin"))
 insDoc(aux1, gLnk("R", "DOSEnergyPoints", "vars/Output.html#DOSEnergyPoints"))
@@ -377,15 +407,16 @@ insDoc(aux1, gLnk("R", "LocalMagneticMomentsSphereRadius", "vars/Output.html#Loc
 insDoc(aux1, gLnk("R", "MomentumTransfer", "vars/Output.html#MomentumTransfer"))
 insDoc(aux1, gLnk("R", "OpenSCADIsovalue", "vars/Output.html#OpenSCADIsovalue"))
 insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
-insDoc(aux1, gLnk("R", "OutputBandsGnuplotMode", "vars/Output.html#OutputBandsGnuplotMode"))
-insDoc(aux1, gLnk("R", "OutputBandsGraceMode", "vars/Output.html#OutputBandsGraceMode"))
 insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
 insDoc(aux1, gLnk("R", "OutputFormat", "vars/Output.html#OutputFormat"))
+insDoc(aux1, gLnk("R", "OutputGradientPotential", "vars/Output.html#OutputGradientPotential"))
 insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
 insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
+insDoc(aux1, gLnk("R", "OutputLDA_U", "vars/Output.html#OutputLDA_U"))
 insDoc(aux1, gLnk("R", "OutputMEMultipoles", "vars/Output.html#OutputMEMultipoles"))
 insDoc(aux1, gLnk("R", "OutputMatrixElements", "vars/Output.html#OutputMatrixElements"))
 insDoc(aux1, gLnk("R", "OutputWfsNumber", "vars/Output.html#OutputWfsNumber"))
+insDoc(aux1, gLnk("R", "Output_KPT", "vars/Output.html#Output_KPT"))
 aux2 = insFld(aux1, gFld("BerkeleyGW", "vars/Output.html#Output::BerkeleyGW"))
 insDoc(aux2, gLnk("R", "BerkeleyGW_CalcDipoleMtxels", "vars/Output.html#BerkeleyGW_CalcDipoleMtxels"))
 insDoc(aux2, gLnk("R", "BerkeleyGW_CalcExchange", "vars/Output.html#BerkeleyGW_CalcExchange"))
@@ -420,11 +451,11 @@ insDoc(aux2, gLnk("R", "MaximumIter", "vars/SCF.html#MaximumIter"))
 insDoc(aux2, gLnk("R", "MaximumIterBerry", "vars/SCF.html#MaximumIterBerry"))
 aux2 = insFld(aux1, gFld("Eigensolver", "vars/SCF.html#SCF::Eigensolver"))
 insDoc(aux2, gLnk("R", "Eigensolver", "vars/SCF.html#Eigensolver"))
-insDoc(aux2, gLnk("R", "EigensolverArnoldiVectors", "vars/SCF.html#EigensolverArnoldiVectors"))
 insDoc(aux2, gLnk("R", "EigensolverImaginaryTime", "vars/SCF.html#EigensolverImaginaryTime"))
 insDoc(aux2, gLnk("R", "EigensolverMaxIter", "vars/SCF.html#EigensolverMaxIter"))
 insDoc(aux2, gLnk("R", "EigensolverMinimizationIter", "vars/SCF.html#EigensolverMinimizationIter"))
 insDoc(aux2, gLnk("R", "EigensolverSaveMemory", "vars/SCF.html#EigensolverSaveMemory"))
+insDoc(aux2, gLnk("R", "EigensolverSkipKpoints", "vars/SCF.html#EigensolverSkipKpoints"))
 insDoc(aux2, gLnk("R", "EigensolverTolerance", "vars/SCF.html#EigensolverTolerance"))
 insDoc(aux2, gLnk("R", "Preconditioner", "vars/SCF.html#Preconditioner"))
 insDoc(aux2, gLnk("R", "PreconditionerFilterFactor", "vars/SCF.html#PreconditionerFilterFactor"))
@@ -432,6 +463,7 @@ insDoc(aux2, gLnk("R", "StatesOrthogonalization", "vars/SCF.html#StatesOrthogona
 insDoc(aux2, gLnk("R", "SubspaceDiagonalization", "vars/SCF.html#SubspaceDiagonalization"))
 aux3 = insFld(aux2, gFld("ARPACK", "vars/SCF.html#SCF::Eigensolver::ARPACK"))
 insDoc(aux3, gLnk("R", "ArpackInitialTolerance", "vars/SCF.html#ArpackInitialTolerance"))
+insDoc(aux3, gLnk("R", "EigensolverArnoldiVectors", "vars/SCF.html#EigensolverArnoldiVectors"))
 insDoc(aux3, gLnk("R", "EigensolverArpackInitialResid", "vars/SCF.html#EigensolverArpackInitialResid"))
 insDoc(aux3, gLnk("R", "EigensolverArpackSort", "vars/SCF.html#EigensolverArpackSort"))
 insDoc(aux3, gLnk("R", "EigensolverParpack", "vars/SCF.html#EigensolverParpack"))
@@ -466,6 +498,7 @@ aux1 = insFld(aux0, gFld("States", "vars/States.html#States"))
 insDoc(aux1, gLnk("R", "DegeneracyThreshold", "vars/States.html#DegeneracyThreshold"))
 insDoc(aux1, gLnk("R", "ExcessCharge", "vars/States.html#ExcessCharge"))
 insDoc(aux1, gLnk("R", "ExtraStates", "vars/States.html#ExtraStates"))
+insDoc(aux1, gLnk("R", "ExtraStatesToConverge", "vars/States.html#ExtraStatesToConverge"))
 insDoc(aux1, gLnk("R", "InitialSpins", "vars/States.html#InitialSpins"))
 insDoc(aux1, gLnk("R", "Occupations", "vars/States.html#Occupations"))
 insDoc(aux1, gLnk("R", "OnlyUserDefinedInitialStates", "vars/States.html#OnlyUserDefinedInitialStates"))
@@ -514,8 +547,10 @@ insDoc(aux2, gLnk("R", "XSFVelocities", "vars/System.html#XSFVelocities"))
 insDoc(aux2, gLnk("R", "XYZVelocities", "vars/System.html#XYZVelocities"))
 aux1 = insFld(aux0, gFld("Time-Dependent", "vars/Time-Dependent.html#Time-Dependent"))
 insDoc(aux1, gLnk("R", "TDExternalFields", "vars/Time-Dependent.html#TDExternalFields"))
+insDoc(aux1, gLnk("R", "TDFreezeDFTUOccupations", "vars/Time-Dependent.html#TDFreezeDFTUOccupations"))
 insDoc(aux1, gLnk("R", "TDFreezeHXC", "vars/Time-Dependent.html#TDFreezeHXC"))
 insDoc(aux1, gLnk("R", "TDFreezeOrbitals", "vars/Time-Dependent.html#TDFreezeOrbitals"))
+insDoc(aux1, gLnk("R", "TDFreezeU", "vars/Time-Dependent.html#TDFreezeU"))
 insDoc(aux1, gLnk("R", "TDFunctions", "vars/Time-Dependent.html#TDFunctions"))
 insDoc(aux1, gLnk("R", "TDGlobalForce", "vars/Time-Dependent.html#TDGlobalForce"))
 insDoc(aux1, gLnk("R", "TDScissor", "vars/Time-Dependent.html#TDScissor"))
@@ -601,6 +636,7 @@ insDoc(aux2, gLnk("R", "TDFloquetSample", "vars/Time-Dependent.html#TDFloquetSam
 insDoc(aux2, gLnk("R", "TDMultipoleLmax", "vars/Time-Dependent.html#TDMultipoleLmax"))
 insDoc(aux2, gLnk("R", "TDOutput", "vars/Time-Dependent.html#TDOutput"))
 insDoc(aux2, gLnk("R", "TDOutputComputeInterval", "vars/Time-Dependent.html#TDOutputComputeInterval"))
+insDoc(aux2, gLnk("R", "TDOutputDFTU", "vars/Time-Dependent.html#TDOutputDFTU"))
 insDoc(aux2, gLnk("R", "TDProjStateStart", "vars/Time-Dependent.html#TDProjStateStart"))
 aux1 = insFld(aux0, gFld("Utilities", "vars/Utilities.html#Utilities::"))
 insDoc(aux1, gLnk("R", "Volume", "vars/Utilities.html#Volume"))
