@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002 M. Marques, A. Castro, A. Rubio, G. Bertsch
+ Copyright (C) 2002 M. Marques, A. Castro, A. Rubio, G. Bertsch, D. Strubbe
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: symbols.c 14262 2015-06-12 17:49:58Z dstrubbe $
 */
 
 #include <stdio.h>
@@ -41,7 +40,18 @@ void str_tolower(char *in)
     *in = (char)tolower(*in);
 }
 
-symrec *putsym (const char *sym_name, symrec_type sym_type)
+void sym_mark_table_used ()
+{
+  symrec *ptr;
+
+  for (ptr = sym_table; ptr != (symrec *) 0;
+       ptr = (symrec *)ptr->next)
+  {
+    ptr->used = 1;
+  }
+}
+
+symrec *putsym (const char *sym_name, symrec_type sym_type)  
 {
   symrec *ptr;
   ptr = (symrec *)malloc(sizeof(symrec));
@@ -102,9 +112,22 @@ void sym_notdef (symrec *sym)
   exit(1);
 }
 
+void sym_redef (symrec *sym)
+{
+  fprintf(stderr, "Parser warning: redefining symbol, previous value ");
+  sym_print(stderr, sym);
+  fprintf(stderr, "\n");
+}
+
 void sym_wrong_arg (symrec *sym)
 {
-  fprintf(stderr, "Parser error: function '%s' requires %d argument(s).\n", sym->name, sym->nargs);
+  if(sym->type == S_BLOCK) {
+    fprintf(stderr, "Parser error: block name '%s' used in variable context.\n", sym->name);
+  } else if(sym->type == S_STR) {
+    fprintf(stderr, "Parser error: string variable '%s' used in expression context.\n", sym->name);
+  } else {
+    fprintf(stderr, "Parser error: function '%s' requires %d argument(s).\n", sym->name, sym->nargs);
+  }
   exit(1);
 }
 
@@ -183,10 +206,8 @@ static struct init_cnst arith_cnts[] = {
 	{"e",      M_E, 0},
 	{"i",        0, 1},
 	{"true",     1, 0}, 
-	{"t",        1, 0}, 
 	{"yes",      1, 0},
 	{"false",    0, 0}, 
-	{"f",        0, 0}, 
 	{"no",       0, 0},
 	{0,          0, 0}
 };
@@ -216,14 +237,6 @@ void sym_init_table ()  /* puts arithmetic functions in table. */
   }
 }
 
-void sym_clear_reserved()
-{
-  int i;
-  for (i = 0; reserved_symbols[i] != 0; i++){
-    rmsym(reserved_symbols[i]);
-  }
-}
-
 void sym_end_table()
 {
   symrec *ptr, *ptr2;
@@ -237,13 +250,6 @@ void sym_end_table()
       break;
     case S_BLOCK:
       if(ptr->value.block->n > 0){
-	for(l = 0; l < ptr->value.block->n; l++){
-	  if(ptr->value.block->lines[l].n > 0){
-	    for(col = 0; col < ptr->value.block->lines[l].n; col++)
-	      free(ptr->value.block->lines[l].fields[col]);
-	    free(ptr->value.block->lines[l].fields);
-	  }
-	}
 	free(ptr->value.block->lines);
       }
       free(ptr->value.block);
@@ -260,25 +266,60 @@ void sym_end_table()
   sym_table = NULL;
 }
 
-void sym_output_table(int only_unused)
+/* this function is defined in src/basic/varinfo_low.c */
+int varinfo_variable_exists(const char * var_name);
+
+void sym_output_table(int only_unused, int mpiv_node)
 {
+  FILE *f;
   symrec *ptr;
+  int any_unused = 0;
+
+  if(mpiv_node != 0) {
+    return;
+  }
+  
+  if(only_unused) {
+    f = stderr;
+  } else {
+    f = stdout;
+  }
+  
   for(ptr = sym_table; ptr != NULL; ptr = ptr->next){
     if(only_unused && ptr->used == 1) continue;
-    printf("%s", ptr->name);
-    switch(ptr->type){
-    case S_CMPLX:
-      printf(" = (%f,%f)\n", GSL_REAL(ptr->value.c), GSL_IMAG(ptr->value.c));
-      break;
-    case S_STR:
-      printf(" = \"%s\"\n", ptr->value.str);
-      break;
-    case S_BLOCK:
-      printf("%s\n", " <= BLOCK");
-      break;
-    case S_FNCT:
-      printf("%s\n", " <= FUNCTION");
-      break;
+    if(only_unused && varinfo_variable_exists(ptr->name)) continue;
+    if(any_unused == 0) {
+      fprintf(f, "\nParser warning: possible mistakes in input file.\n");
+      fprintf(f, "List of variable assignments not used by parser:\n");
+      any_unused = 1;
     }
+
+    sym_print(f, ptr);
+  }
+  if(any_unused == 1) {
+    fprintf(f, "\n");
+  }
+}
+
+void sym_print(FILE *f, const symrec *ptr)
+{
+  fprintf(f, "%s", ptr->name);
+  switch(ptr->type){
+  case S_CMPLX:
+    if(fabs(GSL_IMAG(ptr->value.c)) < 1.0e-14){
+      fprintf(f, " = %f\n", GSL_REAL(ptr->value.c));
+    } else {
+      fprintf(f, " = (%f,%f)\n", GSL_REAL(ptr->value.c), GSL_IMAG(ptr->value.c));
+    }
+    break;
+  case S_STR:
+    fprintf(f, " = \"%s\"\n", ptr->value.str);
+    break;
+  case S_BLOCK:
+    fprintf(f, "%s\n", " <= BLOCK");
+    break;
+  case S_FNCT:
+    fprintf(f, "%s\n", " <= FUNCTION");
+    break;
   }
 }
