@@ -16,7 +16,6 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id$
 */
 
 #ifndef __CL_COMPLEX_H__
@@ -25,11 +24,19 @@
 #include <cl_global.h>
 
 inline double2 complex_conj(const double2 a){
-  return (double2) (a.x, -a.y);
+#ifdef CUDA
+  return double2(a.x, -a.y);
+#else
+    return (double2) (a.x, -a.y);
+#endif
 }
 
 inline double2 complex_mul(const double2 a, const double2 b){
-  return (double2) (a.x*b.x - a.y*b.y, a.y*b.x + a.x*b.y);
+#ifdef CUDA
+  return double2(a.x*b.x - a.y*b.y, a.y*b.x + a.x*b.y);
+#else
+  return (double2)(a.x*b.x - a.y*b.y, a.y*b.x + a.x*b.y);
+#endif
 }
 
 inline double2 complex_div(const double2 a, const double2 b){
